@@ -637,6 +637,11 @@ impl Source {
             .map(|s| self.parse_relations(&s))
     }
 
+    /// Set the Build-Depends-Indep field
+    pub fn set_build_depends_indep(&mut self, relations: &Relations) {
+        self.set("Build-Depends-Indep", relations.to_string().as_str());
+    }
+
     /// Return the Build-Depends-Arch field
     pub fn build_depends_arch(&self) -> Option<Relations> {
         self.paragraph
@@ -644,6 +649,11 @@ impl Source {
             .map(|s| self.parse_relations(&s))
     }
 
+    /// Set the Build-Depends-Arch field
+    pub fn set_build_depends_arch(&mut self, relations: &Relations) {
+        self.set("Build-Depends-Arch", relations.to_string().as_str());
+    }
+
     /// The build conflicts of the package.
     pub fn build_conflicts(&self) -> Option<Relations> {
         self.paragraph
@@ -651,6 +661,11 @@ impl Source {
             .map(|s| self.parse_relations(&s))
     }
 
+    /// Set the Build-Conflicts field
+    pub fn set_build_conflicts(&mut self, relations: &Relations) {
+        self.set("Build-Conflicts", relations.to_string().as_str());
+    }
+
     /// Return the Build-Conflicts-Indep field
     pub fn build_conflicts_indep(&self) -> Option<Relations> {
         self.paragraph
@@ -658,6 +673,11 @@ impl Source {
             .map(|s| self.parse_relations(&s))
     }
 
+    /// Set the Build-Conflicts-Indep field
+    pub fn set_build_conflicts_indep(&mut self, relations: &Relations) {
+        self.set("Build-Conflicts-Indep", relations.to_string().as_str());
+    }
+
     /// Return the Build-Conflicts-Arch field
     pub fn build_conflicts_arch(&self) -> Option<Relations> {
         self.paragraph
